# -*- coding: utf-8 -*-

from django.test import TestCase
from django_envie.workroom import convertfiletovars, BASE_DIR

import os


class DjangoEnvieTestCase(TestCase):
    def test_py_inside_project(self):
        filepath = os.path.join('.env.py')
        with open(filepath, 'w+') as f:
            f.write('SECRET_KEY = "Not so secret"')
        convertfiletovars()
        secret_key = os.getenv('SECRET_KEY')
        self.assertEqual(secret_key, 'Not so secret')
        os.remove(filepath)
        del os.environ['SECRET_KEY']

    def test_yml_inside_project(self):
        filepath = os.path.join('.env.yml')
        with open(filepath, 'w+') as f:
            f.write('SECRET_KEY : "Not so secret"')
        convertfiletovars()
        secret_key = os.getenv('SECRET_KEY')
        self.assertEqual(secret_key, 'Not so secret')
        os.remove(filepath)
        del os.environ['SECRET_KEY']

    def test_py_outside_project(self):
        filepath = os.path.join(BASE_DIR, '..', '.env.py')
        with open(filepath, 'w+') as f:
            f.write('SECRET_KEY = "Not so secret"')
        convertfiletovars()
        secret_key = os.getenv('SECRET_KEY')
        self.assertEqual(secret_key, 'Not so secret')
        os.remove(filepath)
        del os.environ['SECRET_KEY']

    def test_yml_outside_project(self):
        filepath = os.path.join(BASE_DIR, '..', '.env.yml')
        with open(filepath, 'w+') as f:
            f.write('SECRET_KEY : "Not so secret"')
        convertfiletovars()
        # import pdb; pdb.set_trace()
        secret_key = os.getenv('SECRET_KEY')
        self.assertEqual(secret_key, 'Not so secret')
        os.remove(filepath)
        del os.environ['SECRET_KEY']

    def test_an_error_msg_when_no_yml(self):
        res = convertfiletovars()
        self.assertIn('No environment file', res)



from re import search
import os



BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

ERROR = "No environment file found in your project directory. Go ahead and create one."

PYENV = '.env.py'
YAMLENV = '.env.yml'


def convertfiletovars():
    """
    Set environment variables from .env.py or .env.yml
    if it exists in the project dir.
    """
    FLAG_ERROR = False
    res = None
    # check if env.py exists

    pyfilepath = os.path.join(BASE_DIR, PYENV)
    yamlfilepath = os.path.join(BASE_DIR, YAMLENV)
    if os.path.isfile(pyfilepath):
        res = parse_file(pyfilepath)
    elif os.path.isfile(yamlfilepath):
        res = parse_file(yamlfilepath)
    else:
        # Backtrack to root directory
        pyfilepath = os.path.join(BASE_DIR, '..', PYENV)
        yamlfilepath = os.path.join(BASE_DIR, '..', YAMLENV)
        if os.path.isfile(pyfilepath):
            res = parse_file(pyfilepath)
        elif os.path.isfile(yamlfilepath):
            res = parse_file(yamlfilepath)
        elif not os.path.isfile(pyfilepath) and not os.path.isfile(yamlfilepath):
            FLAG_ERROR = True

    if FLAG_ERROR is True:
        return ERROR
    if res:
        return res.message


def parse_file(file_path):
    file_extension = file_path.split('.')[-1]

    if file_extension == 'py':
        try:
            pyfile = open(file_path, 'r')
            for setting in pyfile.readlines():
                match = search("(\w+)\s=\s\"(.*?)\"", setting)
                key, value = match.groups()
                os.environ.update({key: value})
        except Exception as e:
            return e

    elif file_extension == 'yml':
        from yaml import load
        try:
            environ_data = load(file(file_path, 'r'))
            for key, value in environ_data.iteritems():
                os.environ.update({key: value})
        except Exception as e:
            return e



import re
import os

try:
    from setuptools import setup
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup

setup(
    name="django-envie",
    version="0.0.8",
    description="A module for Django that allows your app to"
    " use environment variables in a file",
    long_description="Django-envie helps your Django app to be"
    " aware of environment variables set in a .py or .yml file.",
    author="Oluwafemi Sule",
    author_email="oluwafemi.sule@andela.com",
    url="https://github.com/andela-osule/django-envie",
    download_url="https://github.com/andela-osule/django-envie.git",
    license="MIT License",
    packages=[
        "django_envie",
    ],
    include_package_data=True,
    install_requires=[
        "Django>=1.8.0",
        "PyYAML>=3.11"
    ],
    tests_require=[
        "nose",
        "coverage",
    ],
    zip_safe=False,
    test_suite="tests.runtests.start",
    classifiers=[
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
